% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/controlchart.R
\name{control.limits.x}
\alias{control.limits.x}
\title{Limits for control chart \emph{x} - Only intended for developer use}
\usage{
control.limits.x(x, method = "range", group.size, L)
}
\arguments{
\item{x}{a numeric vector of data values.}

\item{method}{a character string specifying the preferred estimate of standard deviation parameter.

Possible options are
\itemize{
  \item{\code{"range"}} {for estimation based on sample ranges}
  \item{\code{"sd"}} {for estimation based on sample standard deviations}
}}

\item{group.size}{a positive integer giving the number of observations in individual segments used for computation of control chart limits.
If the data can not be equidistantly divided, the first extra values will be excluded from the analysis.}

\item{L}{a positive numeric value giving parameter \code{L} specifying the width of control limits.}
}
\value{
A list is returned with elements:
\item{x}{a numeric vector of data}
\item{mean}{a numeric value giving sample mean of vector \code{x}}
\item{groups.count}{a numeric value giving a number of segments used for estimating parameters of control chart}
\item{groups.mean}{a numeric vector giving sample means in individual segments used for estimating parameters of control chart}
\item{LCL}{numeric value giving lower control limit of control chart \emph{x}}
\item{UCL}{numeric value giving upper control limit of control chart \emph{s}}
}
\description{
Estimation of limits of control chart \emph{x}. The function is called by \code{\link{KRDetect.outliers.controlchart}} and is not intended for use by regular users of the package.
}
\details{
This function computes parameters based on which control chart \emph{x} can be constructed.
The function is exported for developer use only. It does not perform any checks on inputs since it is only a convenience function for identification limits based on control chart \emph{x}.
}
\references{
Shewhart W (1931). Quality control chart. Bell System Technical Journal, 5, 593–603.

SAS/QC User's Guide, Version 8, 1999. SAS Institute, Cary, N.C.

Wild C, Seber G (2000). Chance encounters: A first course in data analysis and inference. New York: John Wiley.
}
